@@ -71,13 +71,15 @@ void MainWindow::showExpanded()
 
 void MainWindow::on_pushButtonStart_clicked()
 {
-    QProcess process;
-    process.start("sh /opt/tenminutecore/script/tenminutecore.sh");
+    QProcess *process;
+            process = new QProcess( this );
+            process->start("sh opt/tenminutecore/script/tenminutecore.sh");
 }
 
 void MainWindow::on_pushButtonStop_clicked()
 {
-    QProcess process;
-    process.start("sh /opt/tenminutecore/script/kill.sh");
-    process.waitForFinished();
+    QProcess *process;
+            process = new QProcess( this );
+            process->start("sh opt/tenminutecore/script/kill.sh");
+            process->waitForFinished();
 }
